#!/bin/bash

if [ "$EUID" -ne 0 ]; then 
  echo "This image has not been configured properly. Please complain to Logan"
  exit 1
fi

change_password () {
  local PASSWORD="$(whiptail --title "Change Password" --nocancel --passwordbox "Enter new password for user \"pi\"" 10 50 3>&1 1>&2 2>&3)"
  if [[ $? != 0 ]]; then return 1; fi
  if [[ "$PASSWORD" == "raspberry" ]]; then
    whiptail --title "Change Password" --nocancel --msgbox "That password sucks. Please use a different one :)" 10 50
    change_password
    return 0
  fi
  if [[ "$(whiptail --nocancel --passwordbox "Confirm new password for user \"pi\"" 10 50 3>&1 1>&2 2>&3)" == "$PASSWORD" ]]; then
    if [[ $? != 0 ]]; then return 1; fi 
    echo -e "pi:$PASSWORD" | chpasswd
  else
    whiptail --title "Change Password" --nocancel --msgbox "Passwords did not match!" 10 50
    change_password
    return 0
  fi
  local OCTOPASS="$(cat /dev/urandom | tr -dc _A-Z-a-z-0-9 | head -c20)"
  echo -e "octoprint:$OCTOPASS" | chpasswd
  local ROOTPASS="$(cat /dev/urandom | tr -dc _A-Z-a-z-0-9 | head -c20)"
  echo -e "root:$ROOTPASS" | chpasswd
  unset OCTOPASS 
  unset ROOTPASS
  unset PASSWORD
}

service_select () {
  local SERVICE_MENU=$(whiptail --separate-output --nocancel --title "Select services" --checklist "Enable/disable services" 0 0 0 \
    "1" "OctoPrint" ON \
    "2" "GUI" ON \
    "3" "SSH" OFF 3>&1 1>&2 2>&3)
  SERVICE_MENU=($SERVICE_MENU)

  for i in "${SERVICE_MENU[@]}"; do
    case $i in
      "1") systemctl enable octoprint ;;
      "2") systemctl set-default graphical.target ;;
      "3")
        ssh-keygen -A
        systemctl enable sshd ;;
    esac
  done
}

screen_timeout() {
  local TIMEOUT=$(whiptail --nocancel --title "Screen Timeout" --inputbox "Input your desired screen timeout in seconds.\nEnter \"off\" to disable the screen timeout." "0" 10 50 "0" 3>&1 1>&2 2>&3) 
  cat > /home/pi/.xprofile << EOF
    xset s ${TIMEOUT}
    xset -dpms 
    exec openbox-session
EOF
}

<< EOF 
main_menu () {
  local MAINMENU=$(whiptail --separate-output --nocancel --title "Pi Setup" --menu "" 10 50 0 \
     "1" "Setup Networking" \
     "2" "Configure services" \
     "3" "Configure screen timeout" \
     "4" "Exit" 3>&1 1>&2 2>&3)

  case $MAINMENU in
    "1") nmtui; main_menu; return 0;;
    "2") service_select; main_menu; return 0;;
    "3") screen_timeout; main_menu; return 0;;
    "4") return 0;;
  esac 
}
EOF

change_password || exit 1
whiptail --title "Network Configuration" --nocancel --msgbox "Setup will now open nmtui, a program to help configure your ethernet/wireless interfaces. Hit Quit when you are done." 10 50
nmtui
service_select || exit 1
screen_timeout || exit 1
rm /etc/systemd/system/getty@tty1.service.d/override.conf 
rm /etc/profile.d/first-time.sh
reboot

